==> atmelwlandriver-3.3.5.6.tar.bz2: atmelwlandriver/src/includes/usb/general.h <==
/* $Id: general.h,v 1.4 2003/11/28 18:03:00 tmpetsos Exp $ */
/***************************************************************************************
	Copyright 2000-2001 ATMEL Corporation.
	
	This file is part of atmel wireless lan drivers.

    Atmel wireless lan drivers is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Atmel wireless lan drivers is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Atmel wireless lan drivers; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

**************************************************************************************/
typedef unsigned int UINT;
typedef unsigned int *PUINT;
typedef unsigned char UCHAR;
typedef unsigned char *PUCHAR;
typedef unsigned long ULONG;
typedef unsigned long *PULONG;
typedef unsigned short USHORT;
typedef unsigned short *PUSHORT;
typedef void VOID;
typedef void *PVOID;

typedef UCHAR BOOLEAN;

#define 	FALSE 			0
#define 	TRUE			1

#define BIN2HEX(x) ((x) < 10 ? (x) + '0' : (x) + 'a'- 10)

#define HEX2BIN(x) \
  ((x) >= '0' && (x) <= '9'? (x)-'0' :\
   (x) >= 'A' && (x) <= 'F' ? (x) - 'A' + 10 :\
   (x) >= 'a' && (x) <= 'f' ? (x) - 'a' + 10 : 0)

#define MIN(x,y) ((x) < (y) ? (x) : (y))
#define MAX(x,y) ((x) < (y) ? (y) : (x))

#define assert(x) \
  do {\
    if (!(x)) \
      printk(KERN_WARNING __FILE__ ":%d assert " #x "failed\n", __LINE__);\
  } while (0)

==> atmelwlandriver-3.4.1.0.tar.bz2: atmelwlandriver/src/includes/usb/general.h <==
/* $Id: general.h,v 1.5 2004/08/25 12:45:53 tmpetsos Exp $ */
/***************************************************************************************
	Copyright 2000-2001 ATMEL Corporation.
	
	This file is part of atmel wireless lan drivers.

    Atmel wireless lan drivers is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Atmel wireless lan drivers is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Atmel wireless lan drivers; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

**************************************************************************************/
typedef u64                     ULONG64;
typedef unsigned int UINT;
typedef unsigned int *PUINT;
typedef unsigned char UCHAR;
typedef char            CHAR;
//typedef unsigned char *PUCHAR;
typedef unsigned char * PUCHAR;
typedef unsigned long ULONG;
typedef unsigned long *PULONG;
typedef unsigned short USHORT;
typedef unsigned short *PUSHORT;
typedef void VOID;
typedef void *PVOID;

typedef UCHAR BOOLEAN;

#define 	FALSE 			0
#define 	TRUE			1

#define BIN2HEX(x) ((x) < 10 ? (x) + '0' : (x) + 'a'- 10)

#define HEX2BIN(x) \
  ((x) >= '0' && (x) <= '9'? (x)-'0' :\
   (x) >= 'A' && (x) <= 'F' ? (x) - 'A' + 10 :\
   (x) >= 'a' && (x) <= 'f' ? (x) - 'a' + 10 : 0)

#define MIN(x,y) ((x) < (y) ? (x) : (y))
#define MAX(x,y) ((x) < (y) ? (y) : (x))

#define assert(x) \
  do {\
    if (!(x)) \
      printk(KERN_WARNING __FILE__ ":%d assert " #x "failed\n", __LINE__);\
  } while (0)
